Module stake

Module stake 

Modules

config
config for staking carries variables that the stake program cares about
instruction
program
state
tools
Utility functions

Constants

MINIMUM_DELINQUENT_EPOCHS_FOR_DEACTIVATION
The minimum number of epochs before stake account that is delegated to a delinquent vote account may be unstaked with StakeInstruction::DeactivateDelinquent
MINIMUM_STAKE_DELEGATIONDeprecated